@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Provide musical cadence chords
 
-our $VERSION = '0.0800';
+our $VERSION = '0.0801';
 
 use Moo;
 use Music::Chord::Note;
@@ -75,8 +75,8 @@ sub cadence {
         else {
             if ( $top =~ /^(.+?)(\d+)$/ ) {
                 my $note   = $1;
-                my $degree = $2;
-                $top = $note . ++$degree;
+                my $octave = $2;
+                $top = $note . ++$octave;
             }
         }
         push @$chord, $top;
@@ -178,7 +178,7 @@ Music::Cadence - Provide musical cadence chords
 
 =head1 VERSION
 
-version 0.0800
+version 0.0801
 
 =head1 SYNOPSIS
 
@@ -317,8 +317,8 @@ is used.
 If the B<type> is C<imperfect>, the B<variation> determines the kind
 of cadence generated.  For C<1>, a C<perfect> cadence is rendered but
 the highest voice is not the tonic.  For C<3>, a C<perfect> cadence is
-rendered but the C<V> chord is replaced with the C<vii diminished>
-chord.
+rendered but (in a major key) the C<V> chord is replaced with the
+C<vii diminished> chord.
 
 Supported cadences are:
 
@@ -360,8 +360,6 @@ L<https://www.musictheoryacademy.com/how-to-read-sheet-music/cadences/>
 
 =head1 TO DO
 
-Use L<Music::Chord::Positions>!
-
 Evaded cadence
 
 Imperfect inverted cadence (2nd variation)
